@@ -232,7 +232,7 @@ class Label(displayio.Group):
             i = 1
         else:
             i = 0
-        old_c = 0
+        tilegrid_count = i
         y_offset = int(
             (
                 self._font.get_glyph(ord("M")).height
@@ -257,11 +257,7 @@ class Label(displayio.Group):
             bottom = max(bottom, y - glyph.dy + y_offset)
             position_y = y - glyph.height - glyph.dy + y_offset
             position_x = x + glyph.dx
-            if (
-                not self._text
-                or old_c >= len(self._text)
-                or character != self._text[old_c]
-            ) and (glyph.width > 0 and glyph.height > 0):
+            if glyph.width > 0 and glyph.height > 0:
                 try:
                     # pylint: disable=unexpected-keyword-arg
                     face = displayio.TileGrid(
@@ -282,34 +278,16 @@ class Label(displayio.Group):
                         x=position_x,
                         y=position_y,
                     )
-                if i < len(self):
-                    self[i] = face
+                if tilegrid_count < len(self):
+                    self[tilegrid_count] = face
                 else:
                     self.append(face)
-            elif self._text and character == self._text[old_c]:
-
-                try:
-                    self[i].position = (position_x, position_y)
-                except AttributeError:
-                    self[i].x = position_x
-                    self[i].y = position_y
-
+                tilegrid_count += 1
             x += glyph.shift_x
-            # TODO skip this for control sequences or non-printables.
             i += 1
-            old_c += 1
-            # skip all non-printables in the old string
-            while (
-                self._text
-                and old_c < len(self._text)
-                and (
-                    self._text[old_c] == "\n"
-                    or not self._font.get_glyph(ord(self._text[old_c]))
-                )
-            ):
-                old_c += 1
         # Remove the rest
-        while len(self) > i:
+
+        while len(self) > tilegrid_count:  # i:
             self.pop()
         self._text = new_text
         self._boundingbox = (left, top, left + right, bottom - top)
